==> flulm_auth-2.0.3.tar.gz: lib/src/utils/logs_interceptors.dart <==
import 'package:dio/dio.dart';
import 'package:logger/logger.dart';

class LogsInterceptors extends InterceptorsWrapper {
  @override
  onRequest(RequestOptions options, RequestInterceptorHandler handler) async {
    var logger = Logger();
    String curl = "curl -X ";
    String method = options.method;
    String url = options.baseUrl + options.path;

    String query = "";

    if (options.data != null && options.data is String) {
      query = options.data;
    } else {
      Map map;

      if (options.queryParameters.isNotEmpty) {
        map = options.queryParameters;
      } else if (options.data is Map) {
        map = options.data;
      } else if (options.data is String) {
      } else if (options.data is FormData) {
        map = {};
        map.addEntries((options.data as FormData).fields);
      } else {
        map = {};
      }
      query = Transformer.urlEncodeMap(map);
    }
    String curlUrl;
    if (method.toLowerCase() == "get") {
      if (query.isNotEmpty) {
        url += (url.contains("?") ? "&" : "?") + query;
      }
      curlUrl = curl + method + " " + "'" + url + "'";
      logger.d(curlUrl);
    } else {
      //dio 接口抓包params有问题，这里用data的
//        if (options.data is Map<dynamic, dynamic>) {
//          String optionsData = Transformer.urlEncodeMap(options.data);
//          query += optionsData;
//        }

      String header = "";
      options.headers.forEach((key, value) {
        header += " -H " + "\"$key:$value\" ";
      });
      header += " -d '" + query + "'";
      curlUrl = curl + method + " " + header + " " + "\"" + url + "\"";
      logger.d(curlUrl);
    }
//
    return super.onRequest(options, handler);
  }

  @override
  onResponse(Response response, ResponseInterceptorHandler handler) async {
    var logger = Logger();

//    if (Config.DEBUG) {
    if (response != null) {
      logger.d('返回参数: ' + response.toString());
    }
//    }
    return super.onResponse(response, handler); // continue
  }

  @override
  onError(DioError err, ErrorInterceptorHandler handler) async {
    var logger = Logger();

//    if (Config.DEBUG) {
    logger.d('请求异常: ' + err.toString());
    logger.d('请求异常信息: ' + err.response?.toString() ?? "");
//    }
    return super.onError(err, handler);
  }
}

==> flulm_auth-2.1.0.tar.gz: lib/src/utils/logs_interceptors.dart <==
import 'package:dio/dio.dart';
import 'package:logger/logger.dart';

class LogsInterceptors extends InterceptorsWrapper {
  @override
  onRequest(RequestOptions options, RequestInterceptorHandler handler) async {
    var logger = Logger();
    String curl = "curl -X ";
    String method = options.method;
    String url = options.baseUrl + options.path;

    String? query = "";

    if (options.data != null && options.data is String) {
      query = options.data;
    } else {
      Map? map;

      if (options.queryParameters.isNotEmpty) {
        map = options.queryParameters;
      } else if (options.data is Map) {
        map = options.data;
      } else if (options.data is String) {
      } else if (options.data is FormData) {
        map = {};
        map.addEntries((options.data as FormData).fields);
      } else {
        map = {};
      }
      query = Transformer.urlEncodeMap(map!);
    }
    String curlUrl;
    if (method.toLowerCase() == "get") {
      if (query!.isNotEmpty) {
        url += (url.contains("?") ? "&" : "?") + query;
      }
      curlUrl = curl + method + " " + "'" + url + "'";
      logger.d(curlUrl);
    } else {
      //dio 接口抓包params有问题，这里用data的
//        if (options.data is Map<dynamic, dynamic>) {
//          String optionsData = Transformer.urlEncodeMap(options.data);
//          query += optionsData;
//        }

      String header = "";
      options.headers.forEach((key, value) {
        header += " -H " + "\"$key:$value\" ";
      });
      header += " -d '" + query! + "'";
      curlUrl = curl + method + " " + header + " " + "\"" + url + "\"";
      logger.d(curlUrl);
    }
//
    return super.onRequest(options, handler);
  }

  @override
  onResponse(Response response, ResponseInterceptorHandler handler) async {
    var logger = Logger();

//    if (Config.DEBUG) {
    if (response != null) {
      logger.d('返回参数: ' + response.toString());
    }
//    }
    return super.onResponse(response, handler); // continue
  }

  @override
  onError(DioError err, ErrorInterceptorHandler handler) async {
    var logger = Logger();

    logger.d('请求异常: ${err.toString()}');
    logger.d('请求异常信息: ${err.response?.toString()}');
    return super.onError(err, handler);
  }
}
